@@ -34,7 +34,7 @@ import shutil
 import subprocess
 import sys
 from tempfile import TemporaryDirectory
-from typing import Optional, Tuple, List, Dict, Any
+from typing import Optional, Tuple, List, Dict, Any, Callable
 from urllib.parse import urlparse
 
 
@@ -52,7 +52,7 @@ from breezy.workingtree import WorkingTree
 
 from ognibuild import DetailedFailure, UnidentifiedError
 from ognibuild.buildlog import InstallFixer, problem_to_upstream_requirement
-from ognibuild.buildsystem import get_buildsystem, NoBuildToolsFound
+from ognibuild.buildsystem import get_buildsystem, NoBuildToolsFound, BuildSystem
 from ognibuild.debian.apt import AptManager
 from ognibuild.debian.build import DEFAULT_BUILDER
 from ognibuild.debian.fix_build import (
@@ -66,7 +66,7 @@ from ognibuild.dist import (  # noqa: F401
     )
 from ognibuild.fix_build import iterate_with_build_fixers, BuildFixer
 
-from ognibuild.session import SessionSetupFailure
+from ognibuild.session import SessionSetupFailure, Session
 from ognibuild.session.plain import PlainSession
 from ognibuild.session.schroot import SchrootSession
 from ognibuild.requirements import (
@@ -132,6 +132,9 @@ from .publish import update_offical_vcs, NoVcsLocation, VcsAlreadySpecified
 from .standards_version import latest_standards_version
 
 
+Kickstarter = Callable[[WorkingTree, str], None]
+
+
 class BuildSystemProcessError(Exception):
     """Error processing buildsystem-specific part of debianization."""
 
@@ -239,8 +242,7 @@ def default_create_dist(session, tree, package, version, target_dir):
                 return ogni_create_dist(
                     session, tree, target_dir,
                     include_controldir=False,
-                    subdir=(package or "package"),
-                    cleanup=False)
+                    subdir=(package or "package"))
             except DetailedFailure as e:
                 if isinstance(
                         e.error,
@@ -248,8 +250,7 @@ def default_create_dist(session, tree, package, version, target_dir):
                     return ogni_create_dist(
                         session, tree, target_dir,
                         include_controldir=True,
-                        subdir=(package or "package"),
-                        cleanup=False)
+                        subdir=(package or "package"))
                 else:
                     raise
     except NoBuildToolsFound:
@@ -627,7 +628,7 @@ def process_default(es, session, wt, subpath, debian_path, upstream_version, met
 def process_cargo(es, session, wt, subpath, debian_path, upstream_version, metadata, compat_release, buildsystem, buildsystem_subpath, kickstart_from_dist):
     wt.branch.generate_revision_history(NULL_REVISION)
     reset_tree(wt, wt.basis_tree(), subpath)
-    from debmutate.debcargo import DebcargoControlShimEditor
+    from debmutate.debcargo import DebcargoControlShimEditor, unmangle_debcargo_version
     crate = metadata.get('X-Cargo-Crate')
     if crate is None:
         crate = metadata['Name'].replace('_', '-')
@@ -635,7 +636,6 @@ def process_cargo(es, session, wt, subpath, debian_path, upstream_version, metad
         wt.mkdir(debian_path)
     if not wt.is_versioned(debian_path):
         wt.add(debian_path)
-    control = es.enter_context(DebcargoControlShimEditor.from_debian_dir(wt.abspath(debian_path), crate, upstream_version))
     # Only set semver_suffix if this is not the latest version
     import semver
     try:
@@ -646,16 +646,31 @@ def process_cargo(es, session, wt, subpath, debian_path, upstream_version, metad
     if data is None:
         raise BuildSystemProcessError(
             buildsystem, 'Crate does not exist' % crate)
+    features = None
+    crate_version = None
     for version_info in data['versions']:
         available_version = semver.VersionInfo.parse(version_info['num'])
         if (available_version.major, available_version.minor) > (desired_version.major, desired_version.minor):
-            control.debcargo_editor['semver_suffix'] = True
+            semver_suffix = True
             break
+        if unmangle_debcargo_version(upstream_version) == version_info['num']:
+            crate_version = version_info['num']
+            features = list(version_info['features'])
+    else:
+        semver_suffix = False
+    control = es.enter_context(DebcargoControlShimEditor.from_debian_dir(wt.abspath(debian_path), crate, crate_version, features))
+    control.debcargo_editor['semver_suffix'] = semver_suffix
     control.debcargo_editor['overlay'] = '.'
     return control
 
 
-PROCESSORS = {
+Processor = Callable[
+    [contextlib.ExitStack, Session, WorkingTree, str, str, str,
+     Dict[str, Any], Optional[str], BuildSystem, str, Kickstarter],
+    ControlEditor]
+
+
+PROCESSORS: Dict[str, Processor] = {
     "setup.py": process_setup_py,
     "npm": process_npm,
     "maven": process_maven,
@@ -667,7 +682,7 @@ PROCESSORS = {
     "golang": process_golang,
     "R": process_r,
     "octave": process_octave,
-    }
+}
 
 
 def source_name_from_directory_name(path):
@@ -983,11 +998,11 @@ def debianize(  # noqa: C901
                 es, session,
                 wt, subpath,
                 debian_path,
-                upstream_version=upstream_version,
-                metadata=metadata, compat_release=compat_release,
-                buildsystem=buildsystem,
-                buildsystem_subpath=buildsystem_subpath,
-                kickstart_from_dist=kickstart_from_dist)
+                upstream_version,
+                metadata, compat_release,
+                buildsystem,
+                buildsystem_subpath,
+                kickstart_from_dist)
 
             source = control.source
 
@@ -1024,15 +1039,17 @@ def debianize(  # noqa: C901
             if requirement and requirement.family == 'apt':
                 if not requirement.satisfied_by(
                         control.binaries, version):
-                    # TODO(jelmer): Eventually, raise an exception here:
-                    # raise DebianizedPackageRequirementMismatch(
-                    #    requirement, control, version,
-                    #    upstream_branch)
                     logging.warning(
                         'Debianized package (binary packages: %r), version %s '
                         'did not satisfy requirement %r. Wrong repository (%s)?',
                         [binary['Package'] for binary in control.binaries],
                         version, requirement, upstream_branch)
+                    raise DebianizedPackageRequirementMismatch(
+                        requirement, control, version,
+                        upstream_branch)
+
+            control.wrap_and_sort()
+            control.sort_binary_packages()
 
         wt.smart_add([wt.abspath(debian_path)])
         wt.commit(
